##  Link Existing Business Capabilities to Catalog Items
If you're using SAP LeanIX Architecture and Road Map Planning, linking existing business capability fact sheets enables you to view suggested SAP solutions on the Transformations tab of the linked fact sheet.
You can link business capability fact sheets to catalog items by:
  * Bulk linking multiple fact sheets from the reference catalog page
  * Linking individual fact sheets from the fact sheet page
